'use strict';

function CimDate() {
}

// CIM format: yyyymmddHHMMSS.mmmmmmsUUU
// ISO-8601 format 1997-07-16T19:20:30.145+01:00
CimDate.prototype.parseCimDateTimeToIso = function(cimDateTime) {
    var result = this.parseCimDateTimeWithOffset(cimDateTime);

    if (result === undefined) {
        return undefined;
    }

    return this.buildIsoDateFromParts(result.dateParts, result.timeZone, true);
};

CimDate.prototype.parseCimDateTimeToTimestamp = function(cimDateTime) {
    var result = this.parseCimDateTimeWithOffset(cimDateTime);

    if (result === undefined) {
        return undefined;
    }

    var dateParts = result.dateParts;

	var dateObject = new Date(dateParts[0], dateParts[1] - 1, dateParts[2], dateParts[3], dateParts[4], dateParts[5], dateParts[6]);
    var dateAsUnixTimestamp = Math.round(dateObject.getTime() / 1000);
    return dateAsUnixTimestamp;
};

CimDate.prototype.parseCimDateTimeWithOffset = function(cimDateTime) {
	if (cimDateTime === undefined) {
		return undefined;
	}

	var dateParts = this.getDateParts(cimDateTime);

	var timeZone = dateParts[8] + dateParts[9];

	var minutesOffset = parseInt(timeZone);

	if (minutesOffset == 0) {
		timeZone = "Z";
	} else {
		var sign = (minutesOffset > 0 ? "+" : "-");
		minutesOffset = Math.abs(minutesOffset);
		timeZone = sign + ("00" + parseInt(minutesOffset / 60)).slice(-2) + ":" + ("00" + minutesOffset % 60).slice(-2);
	}

    var result = {};
    result.dateParts = dateParts;
    result.timeZone = timeZone;
    return result;
};

//CIM format: yyyymmddHHMMSS.mmmmmmsUUU
CimDate.prototype.parseCimDateTimeUTCToIso = function(cimDateTime) {
    if (cimDateTime === undefined) {
        return undefined;
    }

    var dateParts = this.getDateParts(cimDateTime);
   
   // The TimeGenerated is stored in UTC and the offset appears to always be zero. So in order to display the correct
   // agent local time on the dashboard, we get the machine's current timezone and apply it to the event.
	var minutesOffset = new Date().getTimezoneOffset();
	var timeZone = this.convertTimezoneOffsetTo8601(minutesOffset);
		
    return this.buildIsoDateFromParts(dateParts, timeZone, false);
};

CimDate.prototype.getDateParts = function(cimDateTime) {
    var dateParts = cimDateTime.match(/(\d{4})(\d{2})(\d{2})(\d{2})(\d{2})(\d{2})\.(\d{3})(\d{3})(\-|\+)(\d{3})/);
    dateParts.splice(0, 1);
    return dateParts;
};

CimDate.prototype.buildIsoDateFromParts = function(dateParts, timeZone, includeMillisecs) {
    var date = dateParts[0] + "-" + dateParts[1] + "-" + dateParts[2] + "T" + dateParts[3] + ":" + dateParts[4] + ":" + dateParts[5];

    if(includeMillisecs) {
        date = date + "." + dateParts[6];
    } 

    date = date + timeZone; 
    return date;
}

CimDate.prototype.convertTimezoneOffsetTo8601 = function(minutesOffset) {
	var sign = (minutesOffset >= 0 ? "+" : "-");
    minutesOffset = Math.abs(minutesOffset);
    var timeZone = sign + ("00" + parseInt(minutesOffset / 60)).slice(-2) + ":" + ("00" + minutesOffset % 60).slice(-2);
	return timeZone;
};/*CHECKSUM: 
4b0a31dad2f746af49871047b79741c307e47f57 *C:\jenkins\workspace\FmPlugin_release_1.5.19\build\outputs\mainapp\RelWithDebInfo\Checks\CimDate.js
*/ 
