'use strict';

// @importFmJsLib "Results.js"
// @importFmJsLib "Errors.js"

function CriticalEventsCheck() {
    this.checkConfig;
    this.response = {
        info: "",
        result: "",
        data: {}
    };
}

CriticalEventsCheck.prototype.run = function(config) {
	this.checkConfig = config;
    this.response.result = results.FAILING;

	var MAX_RESULTS_SIZE = 10;

    var query = this.buildQuery(this.checkConfig.eventlog, new Date());
    this.response.query = query;
    var queryResult = CriticalEventsAPI.GetCriticalEvents(query, this.isReportMostFrequent(), MAX_RESULTS_SIZE);
	
	if(queryResult.hasError) {
		this.response.data.errorCode = errors[queryResult.error];
		return this.response;
	}
	
	
	var totalCount = parseInt(queryResult.totalEvents);
	
    this.response.data.TotalCount = totalCount;
    this.response.data.Events = queryResult.events;

    if (totalCount == 0 || config.mode == 0) {
        this.response.result = results.PASSING;
    }

    return this.response;
}

CriticalEventsCheck.prototype.buildQuery = function(logFile, now) {
    var twentyFourHoursAgo = new Date(now - 24 * 60 * 60 * 1000);

    var query = "SELECT RecordNumber, TimeGenerated, EventCode, Type, Category, SourceName, Message FROM Win32_NTLogEvent WHERE";
    query += " Logfile='" + logFile + "' AND";

    var twentyFourHoursAgoString = twentyFourHoursAgo.toISOString();
    // 2015-06-30T12:00:59.123Z
    // should be 20150630120059.123000-000, look at Microsoft documentation...
    twentyFourHoursAgoString = twentyFourHoursAgoString.split(/[^\d\.]/).join("") + "000-000";

    query += " ((Type != 'Critical' and EventType=1) or EventType=5) AND TimeGenerated >= '" + twentyFourHoursAgoString + "'";

    return query;
}

CriticalEventsCheck.prototype.isReportMostFrequent = function() {
    return parseInt(this.checkConfig.option) != 1;
}

function getCheck() {
    return new CriticalEventsCheck();
}
/*CHECKSUM: 
c1b50fe332675c1a8464781a53f7e1f0cd622022 *C:\jenkins\workspace\FmPlugin_release_1.5.19\build\outputs\mainapp\RelWithDebInfo\Checks\check_critical_events.js
*/ 
