'use strict';

// @importFmJsLib "Results.js"
// @importFmJsLib "Errors.js"

function DiskSpaceCheck() {
	this.MEMORY_UNIT_PERCENT = 3;
	this.MEMORY_UNIT_BYTES = 0;
	this.MEMORY_UNIT_MBYTES = 1;
	this.MEMORY_UNIT_GBYTES = 2;
	
	this.BYTES_PER_MEGABYTE = 1048576;
	this.BYTES_PER_GIGABYTE = 1073741824;
	
	this.response = {
		info: "",
		result: "",
		data: {
		}
	};	
}

DiskSpaceCheck.prototype.run = function(config) {
   
    this.response.result = results.FAILING;
	
    var apiCall = DiskInfoAPI.Get_Disk_Free_Space(config.driveletter);
          
    if (!apiCall.result) {
        this.response.data.errorCode = errors[apiCall.errorCode];
        return this.response;
    }
    
    if (config.spaceunits == this.MEMORY_UNIT_BYTES) {
        if (apiCall.TotalNumberOfFreeBytes >= config.freespace) {
            this.response.result = results.PASSING;
        }
    }

	var temp;
    if (config.spaceunits == this.MEMORY_UNIT_MBYTES) {
        temp = apiCall.TotalNumberOfFreeBytes / this.BYTES_PER_MEGABYTE;
        if (temp >= config.freespace) {
            this.response.result = results.PASSING;
        }
    }

    if (config.spaceunits == this.MEMORY_UNIT_GBYTES) {
        temp = apiCall.TotalNumberOfFreeBytes / this.BYTES_PER_GIGABYTE;
        if (temp >= config.freespace) {
            this.response.result = results.PASSING;
        }
    }

    if (config.spaceunits == this.MEMORY_UNIT_PERCENT) {
        var tempFree = apiCall.TotalNumberOfFreeBytes / apiCall.TotalNumberOfBytes;
        var threshold = config.freespace / 100.0;
        if (tempFree >= threshold) {
            this.response.result = results.PASSING;
        } 
    }
	
	this.response.data.DiskSize = apiCall.TotalNumberOfBytes / this.BYTES_PER_MEGABYTE
	this.response.data.DiskFree = apiCall.TotalNumberOfFreeBytes / this.BYTES_PER_MEGABYTE;
    return this.response;
};

function getCheck() {
	return new DiskSpaceCheck();
}
/*CHECKSUM: 
e400efa76793cb7b7b87af5b60f998cad4c0e239 *C:\jenkins\workspace\FmPlugin_release_1.5.19\build\outputs\mainapp\RelWithDebInfo\Checks\check_disk_space.js
*/ 
