'use strict';

// @importFmJsLib "Results.js"
// @importFmJsLib "Errors.js"

function DiskSpaceChangeCheck() {
    this.response = {
        info: "",
        result: "",
        data: {}
    };
}

DiskSpaceChangeCheck.prototype.run = function(config) {
    var currentDiskInfo = DiskInfoAPI.Get_Disk_Free_Space(config.driveletter);

    if (!currentDiskInfo.result) {
        this.response.result = results.FAILING;
        this.response.data.errorCode = errors[currentDiskInfo.errorCode];
        return this.response;
    }

    this.response.result = results.PASSING;

    var currentFreeSpacePercentage = (currentDiskInfo.TotalNumberOfFreeBytes / currentDiskInfo.TotalNumberOfBytes) * 100;

    this.response.data.DiskSize = currentDiskInfo.TotalNumberOfBytes / (1024 * 1024);
    this.response.data.DiskFree = currentDiskInfo.TotalNumberOfFreeBytes / (1024 * 1024);
    this.response.data.DiskPercentage = currentFreeSpacePercentage

    var previousConfig = FileSystemAPI.getLastCheckConfig(config.checkid);

    if (previousConfig.driveletter != config.driveletter) {
        this.response.data.DiskChange = 0;
        return this.response;
    }

    var previousResult = FileSystemAPI.getLastCheckResult(config.checkid);

    if (previousResult.isEmpty || isNaN(previousResult.DiskPercentage)) {
        this.response.data.DiskChange = 0;
        return this.response;
    }

    var percentageChange = previousResult.DiskPercentage - currentFreeSpacePercentage;
    this.response.data.DiskChange = percentageChange;

    if (percentageChange >= config.threshold) {
        this.response.result = results.FAILING;
    }
    return this.response;
};

function getCheck() {
    return new DiskSpaceChangeCheck();
}/*CHECKSUM: 
6d2cc5ca2a55a005124ddbc5cb4b26302412d119 *C:\jenkins\workspace\FmPlugin_release_1.5.19\build\outputs\mainapp\RelWithDebInfo\Checks\check_disk_space_change.js
*/ 
