'use strict';

// @importFmJsLib "Results.js"
// @importFmJsLib "Errors.js"

function PerformanceDiskCheck() {
	this.responses = [];

	this.READ_QUEUE_FAIL_TEST = "ReadQueue";
	this.WRITE_QUEUE_FAIL_TEST = "WriteQueue";
	this.DISK_TIME_FAIL_TEST = "DiskTime";
}

PerformanceDiskCheck.prototype.run = function(configList) {
    var apiCall = PerformanceAPI.getPhysicalDiskData();
    
    if (apiCall.error) {
        for (var configKey in configList) {
            var config = configList[configKey];
            this.responses.push(this.runError(config, configKey));
        }
    } else {
        for (var configKey in configList) { 
            var config = configList[configKey];
            if(!apiCall.data[config.instance]) {
            	this.responses.push(this.runError(config, configKey));
            } else {
            	this.responses.push(this.runIndividual(config, apiCall, configKey));
            }
        }
    }
    return this.responses;
}

PerformanceDiskCheck.prototype.runError = function(config, configKey) {
    var response = {
        "checkId": configKey,
        "result": "",
        "data": {}
    };
    response.result = results.FAILING;
    response.data.errorCode = errors.ERROR_PERFCOUNTER_UNABLE_TO_COLLECT;

    return response;
}

PerformanceDiskCheck.prototype.runIndividual = function(config, apiCall, configKey) {
	var response = {
        "checkId": configKey,
        "result": "",
        "data": {}
    };
    response.result = results.FAILING;

		var result = true;

		var failingTests = [];

		if (apiCall.data[config.instance].physicalDiskReadQueue.average > config.threshold1) {
			result = false;
			failingTests.push(this.READ_QUEUE_FAIL_TEST);
		}

		if (apiCall.data[config.instance].physicalDiskWriteQueue.average > config.threshold2) {
			result = false;
			failingTests.push(this.WRITE_QUEUE_FAIL_TEST);
		}

		if (apiCall.data[config.instance].physicalDiskTime.average > config.threshold3) {
			result = false;
			failingTests.push(this.DISK_TIME_FAIL_TEST);
		}

		if (result) {
			response.result = results.PASSING;
		}

		response.data.AvgDiskTimePercentage = Math.round(apiCall.data[config.instance].physicalDiskTime.average * 1000) / 1000;
		response.data.MaxDiskTimePercentage = Math.round(apiCall.data[config.instance].physicalDiskTime.max * 1000) / 1000;
		response.data.AvgReadQueue = Math.round(apiCall.data[config.instance].physicalDiskReadQueue.average * 1000) / 1000;
		response.data.MaxReadQueue = Math.round(apiCall.data[config.instance].physicalDiskReadQueue.max * 1000) / 1000;
		response.data.AvgWriteQueue = Math.round(apiCall.data[config.instance].physicalDiskWriteQueue.average * 1000) / 1000;
		response.data.MaxWriteQueue = Math.round(apiCall.data[config.instance].physicalDiskWriteQueue.max * 1000) / 1000;
		response.data.FailingTests = failingTests;
	
	return response;
};

function getCheck() {
	return new PerformanceDiskCheck();
}/*CHECKSUM: 
174f49f37d7cc4443623d3ecd102d687b9438b4e *C:\jenkins\workspace\FmPlugin_release_1.5.19\build\outputs\mainapp\RelWithDebInfo\Checks\check_performance_disk.js
*/ 
