'use strict';

// @importFmJsLib "Results.js"
// @importFmJsLib "Errors.js"

function PerformanceMemoryCheck() {
    this.responses = [];
    
    this.AVAILABLE_MEMORY_TEST_FAIL = "AvailableMemory";
    this.COMMITTED_MEMORY_TEST_FAIL = "CommittedMemory";
    this.PAGES_PER_SECOND_TEST_FAIL = "PageFaultsSec";
    this.PAGE_FILE_USAGE_TEST_FAIL = "PageFileUsage";
    this.NON_PAGED_MEMORY_TEST_FAIL = "NonPagedMemory";
}

PerformanceMemoryCheck.prototype.run = function(configList) {
    var apiCall = PerformanceAPI.getMemoryData();
    

    if (apiCall.error) {
        for (var configKey in configList) {
            var config = configList[configKey];
            this.responses.push(this.runError(config, configKey));
        }
    } else {
        var totalMemory = MemoryAPI.getPhysicalMemorySizeKB();

        for (var configKey in configList) { 
            var config = configList[configKey];
            this.responses.push(this.runIndividual(config, apiCall, totalMemory, configKey));
        }
    }
    return this.responses;
}

PerformanceMemoryCheck.prototype.runError = function(config, checkId) {
    var response = {
        "checkId": checkId,
        "result": "",
        "data": {}
    };
    response.result = results.FAILING;
    response.data.errorCode = errors.ERROR_PERFCOUNTER_UNABLE_TO_COLLECT;

    return response;
}

PerformanceMemoryCheck.prototype.runIndividual = function(config, apiCall, totalMemory, configKey) {
    var response = {
        "checkId": configKey,
        "result": "",
        "data": {}
    };
    response.result = results.FAILING;

    
        // if instance is null or empty, set it to the default value: 1.5
        if (!config.instance) {
            config.instance = 1.5;
        }

        
        var result = true;
        var failingTests = [];

        if ((apiCall.data.memoryAvailableKiloBytes.average / 1024) < config.threshold1) {
            result = false;
            failingTests.push(this.AVAILABLE_MEMORY_TEST_FAIL);
        }

        if (apiCall.data.memoryCommittedKiloBytes.average > (totalMemory * config.instance)) {
            result = false;
            failingTests.push(this.COMMITTED_MEMORY_TEST_FAIL);
        }

        if (apiCall.data.memoryPagesPerSecond.average > config.threshold2) {
            result = false;
            failingTests.push(this.PAGES_PER_SECOND_TEST_FAIL);
        }

        if (apiCall.data.memoryPercentUsage.average > config.threshold3) {
            result = false;
            failingTests.push(this.PAGE_FILE_USAGE_TEST_FAIL);
        }

        if ((apiCall.data.memoryPoolNonpagedKiloBytes.value / 1024) > config.threshold4) {
            result = false;
            failingTests.push(this.NON_PAGED_MEMORY_TEST_FAIL);
        }

        if (result) {
            response.result = results.PASSING;
        }

        response.data.MinAvailableMB = Math.round(apiCall.data.memoryAvailableKiloBytes.min / 1024);
        response.data.AvgAvailableMB = Math.round(apiCall.data.memoryAvailableKiloBytes.average / 1024);
        response.data.TotalMemoryMB = Math.round(totalMemory / 1024);
        response.data.MaxCommittedMB = Math.round(apiCall.data.memoryCommittedKiloBytes.max / 1024);
        response.data.AvgCommittedMB = Math.round(apiCall.data.memoryCommittedKiloBytes.average / 1024);
        response.data.MaxPageFaultsPerSecond = Math.round(apiCall.data.memoryPagesPerSecond.max);
        response.data.AvgPageFaultsPerSecond = Math.round(apiCall.data.memoryPagesPerSecond.average);
        response.data.AvgPageFilesUsagePercent = Math.round(apiCall.data.memoryPercentUsage.average);
        response.data.MaxPageFilesUsagePercent = Math.round(apiCall.data.memoryPercentUsage.max);
        response.data.NonPagesMemoryMB = Math.round(apiCall.data.memoryPoolNonpagedKiloBytes.value / 1024);
        response.data.FailingTests = failingTests;
    

    return response;
};

function getCheck() {
    return new PerformanceMemoryCheck();
}/*CHECKSUM: 
16e885cb2a49fc042f14a0e3b55ecb4ec54407b8 *C:\jenkins\workspace\FmPlugin_release_1.5.19\build\outputs\mainapp\RelWithDebInfo\Checks\check_performance_memory.js
*/ 
