'use strict';

// @importFmJsLib "Results.js"
// @importFmJsLib "Errors.js"

function PerformanceNetworkCheck() {
	this.responses = [];
}

PerformanceNetworkCheck.prototype.run = function(configList) {
    var apiCall = PerformanceAPI.getNetworkData();
    
    if (apiCall.error) {
        for (var configKey in configList) {
            var config = configList[configKey];
            this.responses.push(this.runError(config, configKey, errors.ERROR_PERFCOUNTER_UNABLE_TO_COLLECT));
        }
    } else {
        for (var configKey in configList) { 
            var config = configList[configKey];
            if(!apiCall.data[config.instance]) {
            	this.responses.push(this.runError(config, configKey, errors.ERROR_PERFCOUNTER_UNABLE_TO_GET_BANDWIDTH));
            } else {
            	this.responses.push(this.runIndividual(config, apiCall, configKey));
            }
        }
    }
    return this.responses;
}

PerformanceNetworkCheck.prototype.runError = function(config, configKey, errorCode) {
    var response = {
        "checkId": configKey,
        "result": "",
        "data": {}
    };
    response.result = results.FAILING;
    response.data.errorCode = errorCode;

    return response;
}

PerformanceNetworkCheck.prototype.runIndividual = function(config, apiCall, configKey) {
	var response = {
        "checkId": configKey,
        "result": "",
        "data": {}
    };
    response.result = results.FAILING;
	
	var interfaceBandwidthBytes = apiCall.data[config.instance].networkCurrentBandwidth.value / 8;
		
	if (interfaceBandwidthBytes == 0) {
		response.data.errorCode = errors.ERROR_PERFCOUNTER_UNABLE_TO_GET_BANDWIDTH;
	} else {
		var avgUsagePercent = (1024 * 100 * apiCall.data[config.instance].networkKiloBytesTotalPerSec.average) / interfaceBandwidthBytes;
		
		response.data.InterfaceBandwidthBytes = interfaceBandwidthBytes;
		response.data.AvgUsagePercent = Math.round(avgUsagePercent);
		response.data.AvgTotalKBSecond = Math.round(apiCall.data[config.instance].networkKiloBytesTotalPerSec.average);
		response.data.MaxTotalKBSecond = Math.round(apiCall.data[config.instance].networkKiloBytesTotalPerSec.max);
		response.data.AvgSentKBSecond = Math.round(apiCall.data[config.instance].networkKiloBytesSentPerSec.average);
		response.data.MaxSentKBSecond = Math.round(apiCall.data[config.instance].networkKiloBytesSentPerSec.max);
		response.data.AvgReceivedKBSecond = Math.round(apiCall.data[config.instance].networkKiloBytesReceivedPerSec.average);
		response.data.MaxReceivedKBSecond = Math.round(apiCall.data[config.instance].networkKiloBytesReceivedPerSec.max);
		
		if(avgUsagePercent <= config.threshold1) {
			response.result = results.PASSING;
		}
	}
		
		
	return response;
};

function getCheck() {
	return new PerformanceNetworkCheck();
}
/*CHECKSUM: 
881d9f7466f48ad9e0c7acd10f4ac16c74b7aeb0 *C:\jenkins\workspace\FmPlugin_release_1.5.19\build\outputs\mainapp\RelWithDebInfo\Checks\check_performance_network.js
*/ 
