'use strict';

// @importFmJsLib "Results.js"
// @importFmJsLib "Errors.js"

function PerformanceProcessorQueueCheck() {
	this.responses = [];
}

PerformanceProcessorQueueCheck.prototype.run = function(configList) {
    var apiCall = PerformanceAPI.getProcessorQueueData();
    
    if (apiCall.error) {
        for (var configKey in configList) {
            var config = configList[configKey];
            this.responses.push(this.runError(config, configKey));
        }
    } else {
        var numberProcessors = ProcessorAPI.getNumberOfProcessors();

        for (var configKey in configList) { 
            var config = configList[configKey];
            this.responses.push(this.runIndividual(config, apiCall, numberProcessors, configKey));
        }
    }
    return this.responses;
}

PerformanceProcessorQueueCheck.prototype.runError = function(config, checkId) {
    var response = {
        "checkId": checkId,
        "result": "",
        "data": {}
    };
    response.result = results.FAILING;
    response.data.errorCode = errors.ERROR_PERFCOUNTER_UNABLE_TO_COLLECT;

    return response;
}

PerformanceProcessorQueueCheck.prototype.runIndividual = function(config, apiCall, numberProcessors, configKey) {
	var response = {
        "checkId": configKey,
        "result": "",
        "data": {}
    };
    response.result = results.FAILING;
	
	if (apiCall.data.processorQueue.average <= (config.threshold1 * numberProcessors)) {
		response.result = results.PASSING;
	} 
	
	response.data.ProcessorCount = numberProcessors;
	response.data.AvgQueue = Math.round(apiCall.data.processorQueue.average * 1000) / 1000;
	response.data.MaxQueue = Math.round(apiCall.data.processorQueue.max * 1000) / 1000;
		
	return response;
};

function getCheck() {
	return new PerformanceProcessorQueueCheck();
}
/*CHECKSUM: 
0c50dbec96a500669ee71a6a115e9b5ddc2f3ed3 *C:\jenkins\workspace\FmPlugin_release_1.5.19\build\outputs\mainapp\RelWithDebInfo\Checks\check_performance_processor_queue.js
*/ 
