'use strict';

// @importFmJsLib "Results.js"
// @importFmJsLib "Errors.js"

function PerformanceProcessorUtilisationCheck() {
	this.responses = [];
}

PerformanceProcessorUtilisationCheck.prototype.run = function(configList) {
    var apiCall = PerformanceAPI.getProcessorTimeData();
    
    if (apiCall.error) {
        for (var configKey in configList) {
            var config = configList[configKey];
            this.responses.push(this.runError(config, configKey));
        }
    } else {
        var numberProcessors = ProcessorAPI.getNumberOfProcessors();

        for (var configKey in configList) { 
            var config = configList[configKey];
            this.responses.push(this.runIndividual(config, apiCall, numberProcessors, configKey));
        }
    }
    return this.responses;
}

PerformanceProcessorUtilisationCheck.prototype.runError = function(config, checkId) {
    var response = {
        "checkId": checkId,
        "result": "",
        "data": {}
    };
    response.result = results.FAILING;
    response.data.errorCode = errors.ERROR_PERFCOUNTER_UNABLE_TO_COLLECT;

    return response;
}

PerformanceProcessorUtilisationCheck.prototype.runIndividual = function(config, apiCall, numberProcessors, configKey) {
	var response = {
        "checkId": configKey,
        "result": "",
        "data": {}
    };
   	response.result = results.PASSING;
	var numberProcessors = ProcessorAPI.getNumberOfProcessors();
	response.data.Cores = [];

	for(var i = 0; i < numberProcessors; i++) {
		var item = "processor_" + i.toString();
		if (apiCall.data[item].average > config.threshold1) {
			response.result = results.FAILING;
		}
		response.data.Cores.push({
		MaxPercentage: Math.round(apiCall.data[item].max * 1000) / 1000,
		AvgPercentage: Math.round(apiCall.data[item].average * 1000) / 1000
		});
	}

	response.data.ProcessorCount = numberProcessors;
		
	return response;
};

function getCheck() {
	return new PerformanceProcessorUtilisationCheck();
}
/*CHECKSUM: 
88eaf8d3fc66643b57cccede2a7c27984b0fd96a *C:\jenkins\workspace\FmPlugin_release_1.5.19\build\outputs\mainapp\RelWithDebInfo\Checks\check_performance_processor_utilisation.js
*/ 
