'use strict';

// @importFmJsLib "Results.js"
// @importFmJsLib "Errors.js"

function ScriptCheck() {
  this.response = {
    info: "",
    result: "",
    data: {}
  };
}

ScriptCheck.prototype.run = function(config) {
  var commands = [];
  var options = {};
  var encodedArguments = "";

  if (config.arguments) {
    if (config.arguments.commands) {
      commands = config.arguments.commands;
    }
    if (config.arguments.options) {
      options = config.arguments.options;
    }
    if (config.arguments.encodedArguments) {
      encodedArguments = config.arguments.encodedArguments;
    }
  }

  var argumentString = this.processArguments(commands, options, encodedArguments);
  var apiResponse = ScriptRunnerAPI.runScript(config.scriptname, argumentString, config.scriptlanguage, config.timeout, config.checkid);
  var output = apiResponse.output ? apiResponse.output : "";

  if (apiResponse.failed) {
	var result = results.FAILING;
	if (apiResponse.errorCode) {
	  if (apiResponse.errorCode == 'ERROR_SCRIPT_MISSING_SCRIPT' && this.isExpectedThatScriptMightNotBeThere(config.checkid)) {
		  output = "Script awaiting download";
		  result = results.PASSING;
	  }
	  else {
		this.response.data.errorCode = errors[apiResponse.errorCode];
	  }
    }
	this.response.result = result;
  } else {
    this.response.result = results.PASSING;
  }

  this.response.data.status = apiResponse.status ? apiResponse.status : "";
  this.response.data.returncode = apiResponse.returncode ? apiResponse.returncode : "";
  this.response.data.output = output;

  return this.response;
};

ScriptCheck.prototype.isExpectedThatScriptMightNotBeThere = function(checkId) {
	var previousResult = FileSystemAPI.getLastCheckResult(checkId);
	if (!previousResult) {
		return false;
	}
	if (previousResult.isEmpty) {
		return true;
	}
	return previousResult.output == "Script awaiting download";
}

ScriptCheck.prototype.processArguments = function(commands, options, encodedArguments) {
  var argumentString = "";

  for (var i = 0; i < commands.length; ++i) {
    argumentString = argumentString.concat(" ", commands[i]);
  };

  var optionKey;
  for (optionKey in options) {
    argumentString = argumentString.concat(" -", optionKey);
    if (options[optionKey] !== true) { //second arg set to boolean true if no second arg
      var optionValue = options[optionKey];
      if(optionKey == "password" && optionValue.lastIndexOf("*~_", 0) === 0 && optionValue.lastIndexOf("_~*") === optionValue.length-3) {
        optionValue = EncryptionAPI.decrypt(optionValue.substring(3, optionValue.length-3));
      }
      argumentString = argumentString.concat(" ", optionValue);
    }
  };

  if (encodedArguments.length > 0) {
    argumentString = argumentString.concat(" --encoded-params ", encodedArguments);
  }

  if (argumentString.length > 1) {
    argumentString = argumentString.substring(1); //lose first space
  }

  return argumentString;
}

function getCheck() {
  return new ScriptCheck();
}
/*CHECKSUM: 
41b75fe3e2b65061eaae9fadf2f88219088fb167 *C:\jenkins\workspace\FmPlugin_release_1.5.19\build\outputs\mainapp\RelWithDebInfo\Checks\check_script.js
*/ 
