'use strict';

// @importFmJsLib "Results.js"
// @importFmJsLib "Errors.js"

function ServiceCheck() {
	this.SERVICE_START_PENDING = 0x00000002;
	this.SERVICE_RUNNING = 0x00000004;

	this.response = {
		result: "",
		data: {
			"ConsecutiveRestartCount": 0
		}
	};
}

ServiceCheck.prototype.run = function(config) {
	this.response.result = results.FAILING;

	var apiCall = ServiceCheckAPI.checkServiceRunning(config.servicekeyname);

	if (apiCall.errorCode) {
		this.response.data.errorCode = errors[apiCall.errorCode];
	}

    var serviceStatus = apiCall.serviceStatus;

	var restartAttempted = false;
	if (!apiCall.result) {
        if (!this.passIfStartPendingOk(serviceStatus,config)) {
            if (!apiCall.hasErrors && this.isRestartable(config)) {
                apiCall = ServiceCheckAPI.startService(config.servicekeyname);
                serviceStatus = apiCall.serviceStatus;
                restartAttempted = true;
                if (apiCall.errorCode) {
                    this.response.data.errorCode = errors[apiCall.errorCode];
                } else {
                    delete this.response.data.errorCode;
                }
            } else {
                return this.response;
            }
        }
	}

	if (serviceStatus == this.SERVICE_RUNNING || this.passIfStartPendingOk(serviceStatus,config)) {
		this.response.result = results.PASSING;
	}

	var serviceWasRestarted = (this.response.result == results.PASSING) && restartAttempted;
	if (serviceWasRestarted) {
		this.setRestartCounts(config);
	}

	return this.response;
};

ServiceCheck.prototype.setRestartCounts = function (config) {
    var lastConfig = FileSystemAPI.getLastCheckConfig(config.checkid);
    if (lastConfig.servicekeyname == config.servicekeyname) {
        var previousResult = FileSystemAPI.getLastCheckResult(config.checkid);
        if (previousResult.isEmpty) {
            this.response.data.ConsecutiveRestartCount = 1;
        } else {
            this.response.data.ConsecutiveRestartCount = +previousResult.ConsecutiveRestartCount + 1;
        }
    } else {
        this.response.data.ConsecutiveRestartCount = 1;
    }
};

ServiceCheck.prototype.passIfStartPendingOk = function (serviceStatus,config) {
	return serviceStatus == this.SERVICE_START_PENDING && config.startpendingok == "1";
};

ServiceCheck.prototype.isRestartable = function(config) {
	// config.restartonlyafterreboot hold threshold in minutes
	if (config.restartonlyafterreboot && config.restartonlyafterreboot > 0) {
		return ServiceCheckAPI.getTimeSinceRestartInMinutes() <= config.restartonlyafterreboot;
	}
	// config.restart -> 1 for restart the service, 0 do not restart it
	return  (config.restart == 1);
};

function getCheck() {
	return new ServiceCheck();
}/*CHECKSUM: 
7c9da53ca287d80152caf7bd68516ffb9ba4c743 *C:\jenkins\workspace\FmPlugin_release_1.5.19\build\outputs\mainapp\RelWithDebInfo\Checks\check_service.js
*/ 
