'use strict';

// @importFmJsLib "CheckUtils.js"
// @importFmJsLib "Results.js"

function WebProtectionBandwidthCheck() {
    this.response = {
        info: "",
        result: "",
        data: {}
    };

    this.COUNTER_DEFAULT_VALUE = 0;
    this.checkUtils = new CheckUtils();
}

WebProtectionBandwidthCheck.prototype.run = function(config) {
    var apiCall = SettingsIniAPI.getWebMonCounter(config.uid);
    var previousResult = this.getPreviousResult(config.checkid);
    var currentDate = this.getCurrentDate();
    var totalBandwithInBytes = 0;

    var currentResult = {};

    if (previousResult.date == currentDate) {
        currentResult = previousResult;
        currentResult.counter = this.COUNTER_DEFAULT_VALUE;
    } else {
        currentResult = this.getFirstResult();
    }

    totalBandwithInBytes = currentResult.totalBandwidth * 1024;

    if(apiCall.hasCounters) {
        if (apiCall.date == currentResult.date) {
            currentResult.counter = apiCall.counter;
            totalBandwithInBytes = totalBandwithInBytes + parseInt(apiCall.counter);
            // we need to send this value in kilobytes, not in bytes
            currentResult.totalBandwidth = totalBandwithInBytes / 1024;
        } 
    }

    this.response.data = currentResult;

    var thresholdInBytes = this.checkUtils.getThresholdInBytes(config.threshold, config.units);

    if (totalBandwithInBytes > parseInt(thresholdInBytes)) {
        this.response.result = results.FAILING;
    } else {
        this.response.result = results.PASSING;
    }

    return this.response;
};

WebProtectionBandwidthCheck.prototype.getCurrentDate = function() {
    var today = new Date();
    var dd = today.getDate();
    var mm = today.getMonth() + 1;
    var yyyy = today.getFullYear();

    if (dd < 10) {
        dd = '0' + dd
    }

    if (mm < 10) {
        mm = '0' + mm
    }

    var formattedDate = yyyy + "-" + mm + "-" + dd;
    return (formattedDate);
}

WebProtectionBandwidthCheck.prototype.getFirstResult = function() {
    var firstResult = {};
    firstResult.totalBandwidth = 0;
    firstResult.counter = this.COUNTER_DEFAULT_VALUE;
    firstResult.date = this.getCurrentDate();
    return firstResult;
}

WebProtectionBandwidthCheck.prototype.getPreviousResult = function(checkId) {
    var previousResult = FileSystemAPI.getLastCheckResult(checkId);

    if (previousResult.isEmpty) {
        return this.getFirstResult();
    }
	
    return previousResult;
}

function getCheck() {
    return new WebProtectionBandwidthCheck();
}/*CHECKSUM: 
c5e7d9cfe1cab605762a1234bf7f2eba3bcebae6 *C:\jenkins\workspace\FmPlugin_release_1.5.19\build\outputs\mainapp\RelWithDebInfo\Checks\check_web_protection_bandwidth.js
*/ 
