//-------------------------------------------------------------
// Wrapper script to launch scheduled tasks anc collect output
//-------------------------------------------------------------

var TASK_STATUS_STOPPED    		= 0;
var TASK_STATUS_FAILEDTOSTART   = 2;
var SCRIPT_RUNNER_NET_MISSING_RETURN_CODE = 7;

var sCommand, sCommandExec, sLogParam, UID;
var oShell, oArgs, nReturn, sOutput, oExec;
var sAgentDir, objArgs, nArgCount, nMaxOutput, fReadOutput;

oArgs 		= WScript.Arguments;
nArgCount 	= oArgs.Count();

if ( nArgCount < 2 ) {
	WScript.Quit();
}

//-------------------------------------------------------------
// Get the parameters
//-------------------------------------------------------------
UID 	 	 = oArgs(0);
sCommand 	 = oArgs(1);
sAgentDir 	 = GetAgentDir();
sLogParam 	 = ' -logfile ..\\task_' + UID + '.log';
nMaxOutput	 = 16777216; //16 Mb
fReadOutput  = true;

// Re-insert the double quote character which cannot be passed through command line
sCommand = sCommand.replace(/~!~/g,'\"');

//-------------------------------------------------------------
// Run the script
//-------------------------------------------------------------
oShell = new ActiveXObject("WScript.Shell");
oShell.currentdirectory = sAgentDir + '../scripts';

var oPowershellRegEx = /^powershell.exe\s/,
	oScriptRunnerRegEx = /ScriptRunner.exe/;
if( oPowershellRegEx.test( sCommand ) ) {
	var oCommandFileRegEx = /\.\\.+\.ps1.*$/;
	var sCommandFile = oCommandFileRegEx.exec( sCommand );
	var sPowershellPath = GetPowershellPath( sCommandFile ) + " ";
	var sCommandPrefix = "$p = Get-ExecutionPolicy; &{ Set-ExecutionPolicy RemoteSigned }; ";
	var sCommandSuffix = "; Set-ExecutionPolicy $p; Exit $LASTEXITCODE";
	sCommandExec = sCommand.replace( oCommandFileRegEx, ' -Command ' + sCommandPrefix + sCommandFile + sLogParam + sCommandSuffix ).replace( oPowershellRegEx, sPowershellPath );
} else if( oScriptRunnerRegEx.test( sCommand ) ) {
	sCommandExec = sCommand + sLogParam;
	if( !isNetFramework4Installed() ) {
		StSaveResult( TASK_STATUS_STOPPED, SCRIPT_RUNNER_NET_MISSING_RETURN_CODE, sCommandExec, ".NET Framework was not detected" ) ;
		WScript.Quit();
	}
	
} else {
	sCommandExec = sCommand + sLogParam;
}

try {
	oExec = oShell.Exec( sCommandExec );	
} catch( err ) {
	StSaveResult( TASK_STATUS_FAILEDTOSTART, 0, sCommandExec, "Error: " + err.description );
	WScript.Quit();
}

sOutput = "";
oExec.StdIn.Close(); //#3885
while( oExec.Status == 0 ) {
	if( !oExec.StdOut.AtEndOfStream ) {
		if( fReadOutput ) {
		 
			sOutput = sOutput + oExec.StdOut.ReadAll();
			if( sOutput.length > nMaxOutput ){
				fReadOutput = false;
			}
		}
		else{
			oExec.StdOut.ReadAll();
		}
	}	
	WScript.Sleep( 100 );
} 
nReturn = oExec.ExitCode;
if( nReturn == 0 ) {
	sOutput = sOutput + oExec.StdOut.ReadAll();
} else {
	sOutput = oExec.StdErr.ReadAll()  + sOutput + oExec.StdOut.ReadAll();
}
sOutput = sOutput.substr(0, nMaxOutput);

//-------------------------------------------------------------
// Record the output
//-------------------------------------------------------------

StSaveResult( TASK_STATUS_STOPPED, nReturn, sCommandExec, sOutput ) ;

//-------------------------------------------------------------
// Support functions
//-------------------------------------------------------------

function GetAgentDir() {
	var sPath, sTmp, nLen;
	sPath = WScript.ScriptFullName;
	sTmp = WScript.ScriptName;
	nLen = sPath.length-sTmp.length;
	return sPath.substr( 0, nLen );
}

function GetPowershellPath( insCommandFile ) {
	if( !/^\.\\script_102[34]_3[456789]\.ps1/.test( insCommandFile ) )
		return "powershell.exe";
	
	var sWinDir = oShell.ExpandEnvironmentStrings( "%windir%" );
	var sPowershell32 = sWinDir + "\\SysWOW64\\WindowsPowerShell\\v1.0\\powershell.exe";
	var oFSO = new ActiveXObject( "Scripting.FileSystemObject" );
	return oFSO.FileExists( sPowershell32 ) ? sPowershell32 : "powershell.exe";
}

function StSaveResult( innStatus, innResult, insCommand, insOutput ) {
	var oDoc, oRoot, oIntro, oTaskNode, oAttribute, oOutput, oStatus, oResultCode, oCommand;
	
	oDoc = new ActiveXObject("Microsoft.XMLDOM");
	oDoc.async = false;
	oIntro = oDoc.createProcessingInstruction("xml","version='1.0'")  ;
	oDoc.insertBefore( oIntro, oDoc.childNodes(0) );
	oRoot = oDoc.createElement( "scheduledtask" );
	oDoc.appendChild(oRoot);
	
	oOutput = oDoc.createElement( "output" );
	oStatus = oDoc.createElement( "status" );
	oResultCode = oDoc.createElement( "returncode" );
	oCommand = oDoc.createElement( "command" );
	
	oOutput.text = insOutput;
	oStatus.text = innStatus;
	oResultCode.text = innResult;
	oCommand.text = insCommand
	
	oRoot.appendChild( oStatus );
	oRoot.appendChild( oResultCode );
	oRoot.appendChild( oOutput );
	oRoot.appendChild( oCommand )
	
	WScript.StdOut.WriteLine(oDoc.xml);
}

// Query registry to find out if the .NET framework is installed
function isNetFramework4Installed() {

	var sRegistryKeyForNet4Full = '"HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\NET Framework Setup\\NDP\\v4\\Full"',
		sRegistryKeyForNet4Client = '"HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\NET Framework Setup\\NDP\\v4\\Client"',
		sFullVersion = getInstalledNetVersionForKey(sRegistryKeyForNet4Full),
		sClientVersion = getInstalledNetVersionForKey(sRegistryKeyForNet4Client);

	return sClientVersion != null || sFullVersion != null;
}

// Get the version of the installed .Net framework from the provided registry key or null if not isntalled
function getInstalledNetVersionForKey(registryKeyForNet)
{
	var oShell = new ActiveXObject("WScript.Shell"); 
		oExec = oShell.Exec('REG QUERY ' + registryKeyForNet + ' /v Version'),
		sKeys = oExec.StdOut.ReadAll(),
		sVersionRegistryString = null;

	var sRegex = /Version[ ]+REG_SZ[ ]+([0-9.]+)/g,
		aResult = sRegex.exec(sKeys),
		outsVersion = null;

	if(aResult) {
		outsVersion = aResult[1];
	}
	return outsVersion;
}
